#!/bin/bash

mtatype=`config-get mtatype`
fqdn=`config-get fqdn`
relayhost=`config-get relayhost`
destinations=`config-get destinations`
root=`config-get root`
mynetworks=`config-get mynetworks`

do_postconf() {
    interface=$1
    transport=$2
    postconf inet_interfaces="$interface"
    postconf default_transport="$transport"
    postconf relay_transport="$transport"
    postconf myhostname="$fqdn"
    echo $fqdn > /etc/mailname
    if [ "$fqdn" == "localhost" ]; then
        local_destination="localhost.localdomain, localhost"
    else
        local_destination="$fqdn, localhost.localdomain, localhost"
    fi
    if [ "x${destinations}" == "x" ]; then
        postconf mydestination="$local_destination"
    else
        postconf mydestination="$destinations, $local_destination"
    fi
    postconf mailbox_command="/usr/lib/dovecot/deliver -c /etc/dovecot/dovecot.conf -m \"\${EXTENSION}\""
    if [ "x${mynetworks}" == "x" ]; then
        postconf mynetworks="127.0.0.0/8 [::ffff:127.0.0.0]/104 [::1]/128"
    else
        postconf mynetworks="$mynetworks 127.0.0.0/8 [::ffff:127.0.0.0]/104 [::1]/128"
    fi
}

set_alias() {
    sed -i -e '/JUJU CHARM - START/,/JUJU CHARM - END/d' /etc/aliases
    cat >> /etc/aliases << EOF
# JUJU CHARM - START
root: $root
# JUJU CHARM - END
EOF
    newaliases
}

configure_mastercf() {
    sed -i -e '/JUJU CHARM - START/,/JUJU CHARM - END/d' /etc/postfix/master.cf
    cat >> /etc/postfix/master.cf << EOS
# JUJU CHARM - START
submission inet n       -       -       -       -       smtpd
  -o syslog_name=postfix/submission
  -o smtpd_enforce_tls=yes
smtps     inet  n       -       -       -       -       smtpd
  -o syslog_name=postfix/smtps
  -o smtpd_tls_wrappermode=yes
# JUJU CHARM - END
EOS
}

configure_mta_type() {
    echo "postfix postfix/main_mailer_type select ${1}" | debconf-set-selections
    echo "postfix postfix/mailname string ${fqdn}" | debconf-set-selections
    echo "postfix postfix/root_address string" | debconf-set-selections
}
